@@ -22,6 +22,7 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Dlg/ActionDialog.h>
 #include <Lum/Dlg/Msg.h>
 
 #include <Lum/Button.h>
@@ -33,7 +34,7 @@
 #include "FunctionInput.h"
 #include "Util.h"
 
-class FunctionDialog : public Lum::Dialog
+class FunctionDialog : public Lum::Dlg::ActionDialog
 {
 private:
   Parser                &parser;
@@ -45,7 +46,8 @@ private:
 public:
   FunctionDialog(Parser& parser, Lum::Model::String* function);
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 
@@ -65,7 +67,7 @@ FunctionDialog::FunctionDialog(Parser& parser, Lum::Model::String* function)
   Observe(GetClosedAction());
 }
 
-void FunctionDialog::PreInit()
+Lum::Object* FunctionDialog::GetContent()
 {
   FunctionInput    *input;
   Lum::Label       *label;
@@ -88,12 +90,12 @@ void FunctionDialog::PreInit()
   input->SetString(functionControl);
   panel->Add(input);
 
-  panel->AddSpace();
-  panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
+  return panel;
+}
 
-  SetMain(panel);
-
-  Lum::Dialog::PreInit();
+void FunctionDialog::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+{
+  Lum::Dlg::ActionDialog::CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
 }
 
 void FunctionDialog::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -135,7 +137,7 @@ Parser::Expression* FunctionDialog::GetExpression() const
   return expression;
 }
 
-class FunctionsDialog : public Lum::Dialog
+class FunctionsDialog : public Lum::Dlg::ActionDialog
 {
 private:
   Parser                             &parser;
@@ -152,7 +154,8 @@ private:
 public:
   FunctionsDialog(Parser &parser, Functions* functions);
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 };
@@ -177,7 +180,7 @@ FunctionsDialog::FunctionsDialog(Parser &parser, Functions* functions)
   Observe(GetClosedAction());
 }
 
-void FunctionsDialog::PreInit()
+Lum::Object* FunctionsDialog::GetContent()
 {
   Lum::Panel            *horiz;
   Lum::Table            *table;
@@ -197,7 +200,7 @@ void FunctionsDialog::PreInit()
 
   table=new Lum::Table();
   table->SetFlex(true,true);
-  table->SetMinWidth(Lum::Base::Size::stdCharWidth,35);
+  table->SetMinWidth(Lum::Base::Size::stdCharWidth,30);
   table->GetTableView()->SetMinHeight(Lum::Base::Size::stdCharHeight,6);
   table->SetShowHeader(true);
   //table->GetTableView()->SetAutoHFit(true);
@@ -206,12 +209,12 @@ void FunctionsDialog::PreInit()
   table->SetSelection(selection);
   horiz->Add(table);
 
-  SetMain(Lum::VPanel::Create(true,true)
-          ->Add(horiz)
-          ->AddSpace()
-          ->Add(Lum::ButtonRow::CreateClose(GetClosedAction(),true,false)));
+  return horiz;
+}
 
-  Dialog::PreInit();
+void FunctionsDialog::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+{
+  Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
 }
 
 void FunctionsDialog::AddFunction()
@@ -282,7 +285,7 @@ void FunctionsDialog::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg
   Dialog::Resync(model,msg);
 }
 
-class RegionDialog : public Lum::Dialog
+class RegionDialog : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::StringRef topValue;
@@ -351,7 +354,7 @@ public:
     return true;
   }
 
-  void PreInit()
+  Lum::Object* GetContent()
   {
     Lum::Panel     *vert,*horiz;
     Lum::String    *string;
@@ -390,7 +393,7 @@ public:
     string->SetModel(leftValue);
     horiz->Add(string);
 
-    horiz->AddSpace();
+    horiz->AddSpace(true);
 
     string=new Lum::String();
     string->SetRequestsKeyboard(false);
@@ -421,12 +424,13 @@ public:
     horiz->AddSpace(true);
 
     vert->Add(horiz);
-    vert->AddSpace();
-    vert->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
 
-    SetMain(vert);
+    return vert;
+  }
 
-    Dialog::PreInit();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+  {
+    Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
   }
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
