@@ -93,22 +93,24 @@ void UnitConversion::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg&
 {
   if (model==type && !type->IsNull()) {
     srcUnits->Off();
+    destUnits->Off();
+
     srcUnits->Clear();
     for (size_t i=0; i<units[type->Get()-1]->GetAlternativeCount(); i++) {
       srcUnits->Append(units[type->Get()-1]->GetAlternative(i)->GetName());
     }
-    srcUnits->On();
 
-    destUnits->Off();
     destUnits->Clear();
     for (size_t i=0; i<units[type->Get()-1]->GetAlternativeCount(); i++) {
       destUnits->Append(units[type->Get()-1]->GetAlternative(i)->GetName());
     }
-    destUnits->On();
 
     src->Set(1);
     dest->Set(1);
 
+    srcUnits->On();
+    destUnits->On();
+
     Convert();
   }
   else if (model==value || model==src || model==dest) {
@@ -134,7 +136,7 @@ void UnitConversion::StoreConfig(Lum::Config::Node *top)
 
 void UnitConversion::Convert()
 {
-  if (value->IsNull() || value->Empty()) {
+  if (value->IsNull() || value->Empty() || type->IsNull() || src->IsNull() || dest->IsNull()) {
     result->Set(L"");
     return;
   }
